@@ -22,10 +22,13 @@ def _get_kwargs(
     last_parent_hash: Union[Unset, None, str] = UNSET,
     parent_hash: Union[Unset, None, str] = UNSET,
     show_archived: Union[Unset, None, bool] = UNSET,
-    hide_without_main: Union[Unset, None, bool] = UNSET,
+    include_without_main: Union[Unset, None, bool] = UNSET,
+    include_draft_only: Union[Unset, None, bool] = UNSET,
     is_template: Union[Unset, None, bool] = UNSET,
     kinds: Union[Unset, None, str] = UNSET,
     starred_only: Union[Unset, None, bool] = UNSET,
+    with_deployment_msg: Union[Unset, None, bool] = UNSET,
+    languages: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     pass
 
@@ -50,7 +53,9 @@ def _get_kwargs(
 
     params["show_archived"] = show_archived
 
-    params["hide_without_main"] = hide_without_main
+    params["include_without_main"] = include_without_main
+
+    params["include_draft_only"] = include_draft_only
 
     params["is_template"] = is_template
 
@@ -58,6 +63,10 @@ def _get_kwargs(
 
     params["starred_only"] = starred_only
 
+    params["with_deployment_msg"] = with_deployment_msg
+
+    params["languages"] = languages
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     return {
@@ -112,10 +121,13 @@ def sync_detailed(
     last_parent_hash: Union[Unset, None, str] = UNSET,
     parent_hash: Union[Unset, None, str] = UNSET,
     show_archived: Union[Unset, None, bool] = UNSET,
-    hide_without_main: Union[Unset, None, bool] = UNSET,
+    include_without_main: Union[Unset, None, bool] = UNSET,
+    include_draft_only: Union[Unset, None, bool] = UNSET,
     is_template: Union[Unset, None, bool] = UNSET,
     kinds: Union[Unset, None, str] = UNSET,
     starred_only: Union[Unset, None, bool] = UNSET,
+    with_deployment_msg: Union[Unset, None, bool] = UNSET,
+    languages: Union[Unset, None, str] = UNSET,
 ) -> Response[List["ListScriptsResponse200Item"]]:
     """list all scripts
 
@@ -131,10 +143,13 @@ def sync_detailed(
         last_parent_hash (Union[Unset, None, str]):
         parent_hash (Union[Unset, None, str]):
         show_archived (Union[Unset, None, bool]):
-        hide_without_main (Union[Unset, None, bool]):
+        include_without_main (Union[Unset, None, bool]):
+        include_draft_only (Union[Unset, None, bool]):
         is_template (Union[Unset, None, bool]):
         kinds (Union[Unset, None, str]):
         starred_only (Union[Unset, None, bool]):
+        with_deployment_msg (Union[Unset, None, bool]):
+        languages (Union[Unset, None, str]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -156,10 +171,13 @@ def sync_detailed(
         last_parent_hash=last_parent_hash,
         parent_hash=parent_hash,
         show_archived=show_archived,
-        hide_without_main=hide_without_main,
+        include_without_main=include_without_main,
+        include_draft_only=include_draft_only,
         is_template=is_template,
         kinds=kinds,
         starred_only=starred_only,
+        with_deployment_msg=with_deployment_msg,
+        languages=languages,
     )
 
     response = client.get_httpx_client().request(
@@ -183,10 +201,13 @@ def sync(
     last_parent_hash: Union[Unset, None, str] = UNSET,
     parent_hash: Union[Unset, None, str] = UNSET,
     show_archived: Union[Unset, None, bool] = UNSET,
-    hide_without_main: Union[Unset, None, bool] = UNSET,
+    include_without_main: Union[Unset, None, bool] = UNSET,
+    include_draft_only: Union[Unset, None, bool] = UNSET,
     is_template: Union[Unset, None, bool] = UNSET,
     kinds: Union[Unset, None, str] = UNSET,
     starred_only: Union[Unset, None, bool] = UNSET,
+    with_deployment_msg: Union[Unset, None, bool] = UNSET,
+    languages: Union[Unset, None, str] = UNSET,
 ) -> Optional[List["ListScriptsResponse200Item"]]:
     """list all scripts
 
@@ -202,10 +223,13 @@ def sync(
         last_parent_hash (Union[Unset, None, str]):
         parent_hash (Union[Unset, None, str]):
         show_archived (Union[Unset, None, bool]):
-        hide_without_main (Union[Unset, None, bool]):
+        include_without_main (Union[Unset, None, bool]):
+        include_draft_only (Union[Unset, None, bool]):
         is_template (Union[Unset, None, bool]):
         kinds (Union[Unset, None, str]):
         starred_only (Union[Unset, None, bool]):
+        with_deployment_msg (Union[Unset, None, bool]):
+        languages (Union[Unset, None, str]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -228,10 +252,13 @@ def sync(
         last_parent_hash=last_parent_hash,
         parent_hash=parent_hash,
         show_archived=show_archived,
-        hide_without_main=hide_without_main,
+        include_without_main=include_without_main,
+        include_draft_only=include_draft_only,
         is_template=is_template,
         kinds=kinds,
         starred_only=starred_only,
+        with_deployment_msg=with_deployment_msg,
+        languages=languages,
     ).parsed
 
 
@@ -249,10 +276,13 @@ async def asyncio_detailed(
     last_parent_hash: Union[Unset, None, str] = UNSET,
     parent_hash: Union[Unset, None, str] = UNSET,
     show_archived: Union[Unset, None, bool] = UNSET,
-    hide_without_main: Union[Unset, None, bool] = UNSET,
+    include_without_main: Union[Unset, None, bool] = UNSET,
+    include_draft_only: Union[Unset, None, bool] = UNSET,
     is_template: Union[Unset, None, bool] = UNSET,
     kinds: Union[Unset, None, str] = UNSET,
     starred_only: Union[Unset, None, bool] = UNSET,
+    with_deployment_msg: Union[Unset, None, bool] = UNSET,
+    languages: Union[Unset, None, str] = UNSET,
 ) -> Response[List["ListScriptsResponse200Item"]]:
     """list all scripts
 
@@ -268,10 +298,13 @@ async def asyncio_detailed(
         last_parent_hash (Union[Unset, None, str]):
         parent_hash (Union[Unset, None, str]):
         show_archived (Union[Unset, None, bool]):
-        hide_without_main (Union[Unset, None, bool]):
+        include_without_main (Union[Unset, None, bool]):
+        include_draft_only (Union[Unset, None, bool]):
         is_template (Union[Unset, None, bool]):
         kinds (Union[Unset, None, str]):
         starred_only (Union[Unset, None, bool]):
+        with_deployment_msg (Union[Unset, None, bool]):
+        languages (Union[Unset, None, str]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -293,10 +326,13 @@ async def asyncio_detailed(
         last_parent_hash=last_parent_hash,
         parent_hash=parent_hash,
         show_archived=show_archived,
-        hide_without_main=hide_without_main,
+        include_without_main=include_without_main,
+        include_draft_only=include_draft_only,
         is_template=is_template,
         kinds=kinds,
         starred_only=starred_only,
+        with_deployment_msg=with_deployment_msg,
+        languages=languages,
     )
 
     response = await client.get_async_httpx_client().request(**kwargs)
@@ -318,10 +354,13 @@ async def asyncio(
     last_parent_hash: Union[Unset, None, str] = UNSET,
     parent_hash: Union[Unset, None, str] = UNSET,
     show_archived: Union[Unset, None, bool] = UNSET,
-    hide_without_main: Union[Unset, None, bool] = UNSET,
+    include_without_main: Union[Unset, None, bool] = UNSET,
+    include_draft_only: Union[Unset, None, bool] = UNSET,
     is_template: Union[Unset, None, bool] = UNSET,
     kinds: Union[Unset, None, str] = UNSET,
     starred_only: Union[Unset, None, bool] = UNSET,
+    with_deployment_msg: Union[Unset, None, bool] = UNSET,
+    languages: Union[Unset, None, str] = UNSET,
 ) -> Optional[List["ListScriptsResponse200Item"]]:
     """list all scripts
 
@@ -337,10 +376,13 @@ async def asyncio(
         last_parent_hash (Union[Unset, None, str]):
         parent_hash (Union[Unset, None, str]):
         show_archived (Union[Unset, None, bool]):
-        hide_without_main (Union[Unset, None, bool]):
+        include_without_main (Union[Unset, None, bool]):
+        include_draft_only (Union[Unset, None, bool]):
         is_template (Union[Unset, None, bool]):
         kinds (Union[Unset, None, str]):
         starred_only (Union[Unset, None, bool]):
+        with_deployment_msg (Union[Unset, None, bool]):
+        languages (Union[Unset, None, str]):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
@@ -364,9 +406,12 @@ async def asyncio(
             last_parent_hash=last_parent_hash,
             parent_hash=parent_hash,
             show_archived=show_archived,
-            hide_without_main=hide_without_main,
+            include_without_main=include_without_main,
+            include_draft_only=include_draft_only,
             is_template=is_template,
             kinds=kinds,
             starred_only=starred_only,
+            with_deployment_msg=with_deployment_msg,
+            languages=languages,
         )
     ).parsed
