@@ -1,5 +1,5 @@
 import datetime
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
+from typing import Any, Dict, List, Type, TypeVar, Union
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
@@ -7,10 +7,6 @@ from dateutil.parser import isoparse
 
 from ..types import UNSET, Unset
 
-if TYPE_CHECKING:
-    from ..models.get_input_history_response_200_item_args import GetInputHistoryResponse200ItemArgs
-
-
 T = TypeVar("T", bound="GetInputHistoryResponse200Item")
 
 
@@ -20,7 +16,6 @@ class GetInputHistoryResponse200Item:
     Attributes:
         id (str):
         name (str):
-        args (GetInputHistoryResponse200ItemArgs):
         created_by (str):
         created_at (datetime.datetime):
         is_public (bool):
@@ -29,7 +24,6 @@ class GetInputHistoryResponse200Item:
 
     id: str
     name: str
-    args: "GetInputHistoryResponse200ItemArgs"
     created_by: str
     created_at: datetime.datetime
     is_public: bool
@@ -39,8 +33,6 @@ class GetInputHistoryResponse200Item:
     def to_dict(self) -> Dict[str, Any]:
         id = self.id
         name = self.name
-        args = self.args.to_dict()
-
         created_by = self.created_by
         created_at = self.created_at.isoformat()
 
@@ -53,7 +45,6 @@ class GetInputHistoryResponse200Item:
             {
                 "id": id,
                 "name": name,
-                "args": args,
                 "created_by": created_by,
                 "created_at": created_at,
                 "is_public": is_public,
@@ -66,15 +57,11 @@ class GetInputHistoryResponse200Item:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
-        from ..models.get_input_history_response_200_item_args import GetInputHistoryResponse200ItemArgs
-
         d = src_dict.copy()
         id = d.pop("id")
 
         name = d.pop("name")
 
-        args = GetInputHistoryResponse200ItemArgs.from_dict(d.pop("args"))
-
         created_by = d.pop("created_by")
 
         created_at = isoparse(d.pop("created_at"))
@@ -86,7 +73,6 @@ class GetInputHistoryResponse200Item:
         get_input_history_response_200_item = cls(
             id=id,
             name=name,
-            args=args,
             created_by=created_by,
             created_at=created_at,
             is_public=is_public,
