@@ -40,7 +40,8 @@ class ListNatsTriggersResponse200Item:
         last_server_ping (Union[Unset, datetime.datetime]):
         error (Union[Unset, str]):
         error_handler_path (Union[Unset, str]):
-        error_handler_args (Union[Unset, ListNatsTriggersResponse200ItemErrorHandlerArgs]):
+        error_handler_args (Union[Unset, ListNatsTriggersResponse200ItemErrorHandlerArgs]): The arguments to pass to the
+            script or flow
         retry (Union[Unset, ListNatsTriggersResponse200ItemRetry]):
     """
 
