@@ -40,7 +40,8 @@ class ListPostgresTriggersResponse200Item:
         error (Union[Unset, str]):
         last_server_ping (Union[Unset, datetime.datetime]):
         error_handler_path (Union[Unset, str]):
-        error_handler_args (Union[Unset, ListPostgresTriggersResponse200ItemErrorHandlerArgs]):
+        error_handler_args (Union[Unset, ListPostgresTriggersResponse200ItemErrorHandlerArgs]): The arguments to pass to
+            the script or flow
         retry (Union[Unset, ListPostgresTriggersResponse200ItemRetry]):
     """
 
