@@ -12,12 +12,18 @@ if TYPE_CHECKING:
     from ..models.list_queue_response_200_item_raw_flow_failure_module_retry import (
         ListQueueResponse200ItemRawFlowFailureModuleRetry,
     )
+    from ..models.list_queue_response_200_item_raw_flow_failure_module_skip_if import (
+        ListQueueResponse200ItemRawFlowFailureModuleSkipIf,
+    )
     from ..models.list_queue_response_200_item_raw_flow_failure_module_sleep_type_0 import (
         ListQueueResponse200ItemRawFlowFailureModuleSleepType0,
     )
     from ..models.list_queue_response_200_item_raw_flow_failure_module_sleep_type_1 import (
         ListQueueResponse200ItemRawFlowFailureModuleSleepType1,
     )
+    from ..models.list_queue_response_200_item_raw_flow_failure_module_stop_after_all_iters_if import (
+        ListQueueResponse200ItemRawFlowFailureModuleStopAfterAllItersIf,
+    )
     from ..models.list_queue_response_200_item_raw_flow_failure_module_stop_after_if import (
         ListQueueResponse200ItemRawFlowFailureModuleStopAfterIf,
     )
@@ -36,6 +42,8 @@ class ListQueueResponse200ItemRawFlowFailureModule:
         id (str):
         value (Any):
         stop_after_if (Union[Unset, ListQueueResponse200ItemRawFlowFailureModuleStopAfterIf]):
+        stop_after_all_iters_if (Union[Unset, ListQueueResponse200ItemRawFlowFailureModuleStopAfterAllItersIf]):
+        skip_if (Union[Unset, ListQueueResponse200ItemRawFlowFailureModuleSkipIf]):
         sleep (Union['ListQueueResponse200ItemRawFlowFailureModuleSleepType0',
             'ListQueueResponse200ItemRawFlowFailureModuleSleepType1', Unset]):
         cache_ttl (Union[Unset, float]):
@@ -52,6 +60,8 @@ class ListQueueResponse200ItemRawFlowFailureModule:
     id: str
     value: Any
     stop_after_if: Union[Unset, "ListQueueResponse200ItemRawFlowFailureModuleStopAfterIf"] = UNSET
+    stop_after_all_iters_if: Union[Unset, "ListQueueResponse200ItemRawFlowFailureModuleStopAfterAllItersIf"] = UNSET
+    skip_if: Union[Unset, "ListQueueResponse200ItemRawFlowFailureModuleSkipIf"] = UNSET
     sleep: Union[
         "ListQueueResponse200ItemRawFlowFailureModuleSleepType0",
         "ListQueueResponse200ItemRawFlowFailureModuleSleepType1",
@@ -79,6 +89,14 @@ class ListQueueResponse200ItemRawFlowFailureModule:
         if not isinstance(self.stop_after_if, Unset):
             stop_after_if = self.stop_after_if.to_dict()
 
+        stop_after_all_iters_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = self.stop_after_all_iters_if.to_dict()
+
+        skip_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.skip_if, Unset):
+            skip_if = self.skip_if.to_dict()
+
         sleep: Union[Dict[str, Any], Unset]
         if isinstance(self.sleep, Unset):
             sleep = UNSET
@@ -121,6 +139,10 @@ class ListQueueResponse200ItemRawFlowFailureModule:
         )
         if stop_after_if is not UNSET:
             field_dict["stop_after_if"] = stop_after_if
+        if stop_after_all_iters_if is not UNSET:
+            field_dict["stop_after_all_iters_if"] = stop_after_all_iters_if
+        if skip_if is not UNSET:
+            field_dict["skip_if"] = skip_if
         if sleep is not UNSET:
             field_dict["sleep"] = sleep
         if cache_ttl is not UNSET:
@@ -152,12 +174,18 @@ class ListQueueResponse200ItemRawFlowFailureModule:
         from ..models.list_queue_response_200_item_raw_flow_failure_module_retry import (
             ListQueueResponse200ItemRawFlowFailureModuleRetry,
         )
+        from ..models.list_queue_response_200_item_raw_flow_failure_module_skip_if import (
+            ListQueueResponse200ItemRawFlowFailureModuleSkipIf,
+        )
         from ..models.list_queue_response_200_item_raw_flow_failure_module_sleep_type_0 import (
             ListQueueResponse200ItemRawFlowFailureModuleSleepType0,
         )
         from ..models.list_queue_response_200_item_raw_flow_failure_module_sleep_type_1 import (
             ListQueueResponse200ItemRawFlowFailureModuleSleepType1,
         )
+        from ..models.list_queue_response_200_item_raw_flow_failure_module_stop_after_all_iters_if import (
+            ListQueueResponse200ItemRawFlowFailureModuleStopAfterAllItersIf,
+        )
         from ..models.list_queue_response_200_item_raw_flow_failure_module_stop_after_if import (
             ListQueueResponse200ItemRawFlowFailureModuleStopAfterIf,
         )
@@ -177,6 +205,22 @@ class ListQueueResponse200ItemRawFlowFailureModule:
         else:
             stop_after_if = ListQueueResponse200ItemRawFlowFailureModuleStopAfterIf.from_dict(_stop_after_if)
 
+        _stop_after_all_iters_if = d.pop("stop_after_all_iters_if", UNSET)
+        stop_after_all_iters_if: Union[Unset, ListQueueResponse200ItemRawFlowFailureModuleStopAfterAllItersIf]
+        if isinstance(_stop_after_all_iters_if, Unset):
+            stop_after_all_iters_if = UNSET
+        else:
+            stop_after_all_iters_if = ListQueueResponse200ItemRawFlowFailureModuleStopAfterAllItersIf.from_dict(
+                _stop_after_all_iters_if
+            )
+
+        _skip_if = d.pop("skip_if", UNSET)
+        skip_if: Union[Unset, ListQueueResponse200ItemRawFlowFailureModuleSkipIf]
+        if isinstance(_skip_if, Unset):
+            skip_if = UNSET
+        else:
+            skip_if = ListQueueResponse200ItemRawFlowFailureModuleSkipIf.from_dict(_skip_if)
+
         def _parse_sleep(
             data: object,
         ) -> Union[
@@ -249,6 +293,8 @@ class ListQueueResponse200ItemRawFlowFailureModule:
             id=id,
             value=value,
             stop_after_if=stop_after_if,
+            stop_after_all_iters_if=stop_after_all_iters_if,
+            skip_if=skip_if,
             sleep=sleep,
             cache_ttl=cache_ttl,
             timeout=timeout,
