@@ -14,15 +14,18 @@ class ListQueueResponse200ItemRawFlowModulesItemStopAfterIf:
     Attributes:
         expr (str):
         skip_if_stopped (Union[Unset, bool]):
+        error_message (Union[Unset, str]):
     """
 
     expr: str
     skip_if_stopped: Union[Unset, bool] = UNSET
+    error_message: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         expr = self.expr
         skip_if_stopped = self.skip_if_stopped
+        error_message = self.error_message
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -33,6 +36,8 @@ class ListQueueResponse200ItemRawFlowModulesItemStopAfterIf:
         )
         if skip_if_stopped is not UNSET:
             field_dict["skip_if_stopped"] = skip_if_stopped
+        if error_message is not UNSET:
+            field_dict["error_message"] = error_message
 
         return field_dict
 
@@ -43,9 +48,12 @@ class ListQueueResponse200ItemRawFlowModulesItemStopAfterIf:
 
         skip_if_stopped = d.pop("skip_if_stopped", UNSET)
 
+        error_message = d.pop("error_message", UNSET)
+
         list_queue_response_200_item_raw_flow_modules_item_stop_after_if = cls(
             expr=expr,
             skip_if_stopped=skip_if_stopped,
+            error_message=error_message,
         )
 
         list_queue_response_200_item_raw_flow_modules_item_stop_after_if.additional_properties = d
