@@ -36,6 +36,7 @@ class ListScriptsResponse200Item:
         kind (ListScriptsResponse200ItemKind):
         starred (bool):
         no_main_func (bool):
+        has_preprocessor (bool):
         workspace_id (Union[Unset, str]):
         parent_hashes (Union[Unset, List[str]]): The first element is the direct parent of the script, the second is the
             parent of the first, etc
@@ -48,6 +49,7 @@ class ListScriptsResponse200Item:
         envs (Union[Unset, List[str]]):
         concurrent_limit (Union[Unset, int]):
         concurrency_time_window_s (Union[Unset, int]):
+        concurrency_key (Union[Unset, str]):
         cache_ttl (Union[Unset, float]):
         dedicated_worker (Union[Unset, bool]):
         ws_error_handler_muted (Union[Unset, bool]):
@@ -57,6 +59,7 @@ class ListScriptsResponse200Item:
         delete_after_use (Union[Unset, bool]):
         visible_to_runner_only (Union[Unset, bool]):
         codebase (Union[Unset, str]):
+        on_behalf_of_email (Union[Unset, str]):
     """
 
     hash_: str
@@ -74,6 +77,7 @@ class ListScriptsResponse200Item:
     kind: ListScriptsResponse200ItemKind
     starred: bool
     no_main_func: bool
+    has_preprocessor: bool
     workspace_id: Union[Unset, str] = UNSET
     parent_hashes: Union[Unset, List[str]] = UNSET
     schema: Union[Unset, "ListScriptsResponse200ItemSchema"] = UNSET
@@ -85,6 +89,7 @@ class ListScriptsResponse200Item:
     envs: Union[Unset, List[str]] = UNSET
     concurrent_limit: Union[Unset, int] = UNSET
     concurrency_time_window_s: Union[Unset, int] = UNSET
+    concurrency_key: Union[Unset, str] = UNSET
     cache_ttl: Union[Unset, float] = UNSET
     dedicated_worker: Union[Unset, bool] = UNSET
     ws_error_handler_muted: Union[Unset, bool] = UNSET
@@ -94,6 +99,7 @@ class ListScriptsResponse200Item:
     delete_after_use: Union[Unset, bool] = UNSET
     visible_to_runner_only: Union[Unset, bool] = UNSET
     codebase: Union[Unset, str] = UNSET
+    on_behalf_of_email: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -116,6 +122,7 @@ class ListScriptsResponse200Item:
 
         starred = self.starred
         no_main_func = self.no_main_func
+        has_preprocessor = self.has_preprocessor
         workspace_id = self.workspace_id
         parent_hashes: Union[Unset, List[str]] = UNSET
         if not isinstance(self.parent_hashes, Unset):
@@ -136,6 +143,7 @@ class ListScriptsResponse200Item:
 
         concurrent_limit = self.concurrent_limit
         concurrency_time_window_s = self.concurrency_time_window_s
+        concurrency_key = self.concurrency_key
         cache_ttl = self.cache_ttl
         dedicated_worker = self.dedicated_worker
         ws_error_handler_muted = self.ws_error_handler_muted
@@ -145,6 +153,7 @@ class ListScriptsResponse200Item:
         delete_after_use = self.delete_after_use
         visible_to_runner_only = self.visible_to_runner_only
         codebase = self.codebase
+        on_behalf_of_email = self.on_behalf_of_email
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -165,6 +174,7 @@ class ListScriptsResponse200Item:
                 "kind": kind,
                 "starred": starred,
                 "no_main_func": no_main_func,
+                "has_preprocessor": has_preprocessor,
             }
         )
         if workspace_id is not UNSET:
@@ -189,6 +199,8 @@ class ListScriptsResponse200Item:
             field_dict["concurrent_limit"] = concurrent_limit
         if concurrency_time_window_s is not UNSET:
             field_dict["concurrency_time_window_s"] = concurrency_time_window_s
+        if concurrency_key is not UNSET:
+            field_dict["concurrency_key"] = concurrency_key
         if cache_ttl is not UNSET:
             field_dict["cache_ttl"] = cache_ttl
         if dedicated_worker is not UNSET:
@@ -207,6 +219,8 @@ class ListScriptsResponse200Item:
             field_dict["visible_to_runner_only"] = visible_to_runner_only
         if codebase is not UNSET:
             field_dict["codebase"] = codebase
+        if on_behalf_of_email is not UNSET:
+            field_dict["on_behalf_of_email"] = on_behalf_of_email
 
         return field_dict
 
@@ -246,6 +260,8 @@ class ListScriptsResponse200Item:
 
         no_main_func = d.pop("no_main_func")
 
+        has_preprocessor = d.pop("has_preprocessor")
+
         workspace_id = d.pop("workspace_id", UNSET)
 
         parent_hashes = cast(List[str], d.pop("parent_hashes", UNSET))
@@ -273,6 +289,8 @@ class ListScriptsResponse200Item:
 
         concurrency_time_window_s = d.pop("concurrency_time_window_s", UNSET)
 
+        concurrency_key = d.pop("concurrency_key", UNSET)
+
         cache_ttl = d.pop("cache_ttl", UNSET)
 
         dedicated_worker = d.pop("dedicated_worker", UNSET)
@@ -291,6 +309,8 @@ class ListScriptsResponse200Item:
 
         codebase = d.pop("codebase", UNSET)
 
+        on_behalf_of_email = d.pop("on_behalf_of_email", UNSET)
+
         list_scripts_response_200_item = cls(
             hash_=hash_,
             path=path,
@@ -307,6 +327,7 @@ class ListScriptsResponse200Item:
             kind=kind,
             starred=starred,
             no_main_func=no_main_func,
+            has_preprocessor=has_preprocessor,
             workspace_id=workspace_id,
             parent_hashes=parent_hashes,
             schema=schema,
@@ -318,6 +339,7 @@ class ListScriptsResponse200Item:
             envs=envs,
             concurrent_limit=concurrent_limit,
             concurrency_time_window_s=concurrency_time_window_s,
+            concurrency_key=concurrency_key,
             cache_ttl=cache_ttl,
             dedicated_worker=dedicated_worker,
             ws_error_handler_muted=ws_error_handler_muted,
@@ -327,6 +349,7 @@ class ListScriptsResponse200Item:
             delete_after_use=delete_after_use,
             visible_to_runner_only=visible_to_runner_only,
             codebase=codebase,
+            on_behalf_of_email=on_behalf_of_email,
         )
 
         list_scripts_response_200_item.additional_properties = d
