@@ -42,7 +42,8 @@ class ListSqsTriggersResponse200Item:
         last_server_ping (Union[Unset, datetime.datetime]):
         error (Union[Unset, str]):
         error_handler_path (Union[Unset, str]):
-        error_handler_args (Union[Unset, ListSqsTriggersResponse200ItemErrorHandlerArgs]):
+        error_handler_args (Union[Unset, ListSqsTriggersResponse200ItemErrorHandlerArgs]): The arguments to pass to the
+            script or flow
         retry (Union[Unset, ListSqsTriggersResponse200ItemRetry]):
     """
 
