@@ -1,10 +1,9 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import Any, Dict, List, Type, TypeVar
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
 
 from ..models.open_flow_value_modules_item_sleep_type_0_type import OpenFlowValueModulesItemSleepType0Type
-from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="OpenFlowValueModulesItemSleepType0")
 
@@ -13,41 +12,39 @@ T = TypeVar("T", bound="OpenFlowValueModulesItemSleepType0")
 class OpenFlowValueModulesItemSleepType0:
     """
     Attributes:
+        value (Any):
         type (OpenFlowValueModulesItemSleepType0Type):
-        value (Union[Unset, Any]):
     """
 
+    value: Any
     type: OpenFlowValueModulesItemSleepType0Type
-    value: Union[Unset, Any] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
-        type = self.type.value
-
         value = self.value
+        type = self.type.value
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
             {
+                "value": value,
                 "type": type,
             }
         )
-        if value is not UNSET:
-            field_dict["value"] = value
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
+        value = d.pop("value")
+
         type = OpenFlowValueModulesItemSleepType0Type(d.pop("type"))
 
-        value = d.pop("value", UNSET)
-
         open_flow_value_modules_item_sleep_type_0 = cls(
-            type=type,
             value=value,
+            type=type,
         )
 
         open_flow_value_modules_item_sleep_type_0.additional_properties = d
