@@ -23,6 +23,7 @@ class WhoamiResponse200:
         disabled (bool):
         folders (List[str]):
         folders_owners (List[str]):
+        name (Union[Unset, str]):
         groups (Union[Unset, List[str]]):
     """
 
@@ -35,6 +36,7 @@ class WhoamiResponse200:
     disabled: bool
     folders: List[str]
     folders_owners: List[str]
+    name: Union[Unset, str] = UNSET
     groups: Union[Unset, List[str]] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
@@ -51,6 +53,7 @@ class WhoamiResponse200:
 
         folders_owners = self.folders_owners
 
+        name = self.name
         groups: Union[Unset, List[str]] = UNSET
         if not isinstance(self.groups, Unset):
             groups = self.groups
@@ -70,6 +73,8 @@ class WhoamiResponse200:
                 "folders_owners": folders_owners,
             }
         )
+        if name is not UNSET:
+            field_dict["name"] = name
         if groups is not UNSET:
             field_dict["groups"] = groups
 
@@ -96,6 +101,8 @@ class WhoamiResponse200:
 
         folders_owners = cast(List[str], d.pop("folders_owners"))
 
+        name = d.pop("name", UNSET)
+
         groups = cast(List[str], d.pop("groups", UNSET))
 
         whoami_response_200 = cls(
@@ -108,6 +115,7 @@ class WhoamiResponse200:
             disabled=disabled,
             folders=folders,
             folders_owners=folders_owners,
+            name=name,
             groups=groups,
         )
 
